@@ -3,7 +3,7 @@ use warnings;
 
 package Try::ALRM;
 
-our $VERSION = q{0.6};
+our $VERSION = q{0.7};
 
 use Exporter qw/import/;
 our @EXPORT    = qw(try_once retry ALRM finally timeout tries);
@@ -48,10 +48,11 @@ sub retry(&;@) {
     my $tries   = $TODO->{tries}   // $TRIES;
     my $FINALLY = $TODO->{finally} // sub { };
 
-    my ( $attempts, $succeeded );
-
     local $TIMEOUT = $timeout;                       # make available to timeout(;$)
     local $TRIES   = $tries;                         # make available to tries(;$)
+
+    my ( $attempts, $succeeded );
+
   TIMED_ATTEMPTS:
     for my $attempt ( 1 .. $TRIES ) {
         $attempts = $attempt;
@@ -111,49 +112,12 @@ __END__
 
 =head1 NAME
 
-Try::ALRM - Provides C<try_once> and C<retry> semantics to C<CORE::alarm>, similar to C<Try::Catch>.
-
-=head1 FRIENDLY TESTING AND FEEDBACK REQUESTED 
-
-While the utility of this module should be clear, there are a few factors that require a
-maturing. These issues are addressed throughout the documentation below. Using the module
-and providing feedback about it will be extremely appreciated. Please do so at the Github
-repo.
+Try::ALRM - Provides C<try_once> and C<retry> semantics to C<CORE::alarm>, similar to
+L<Try::Tiny>.
 
 =head1 SYNOPSIS
 
-=head2 C<try_once>
-
-    use Try::ALRM;
-     
-    try_once {
-      my ($attempts) = @_;                # @_ is populated as described in this line
-      print qq{ doing something that might timeout ...\n};
-      sleep 6;
-    }
-    ALRM {
-      my ($attempts) = @_;                # @_ is populated as described in this line
-      print qq{ Wake Up!!!!\n};
-    }
-    finally {
-      my ( $attempts, $success ) = @_;    # Note: @_ is populated as described in this line when called with retry
-      my $tries   = tries;                # "what was the limit on number of tries?" Here it will be 4
-      my $timeout = timeout;              # "what was the timeout allowed?" Here it will be 3
-      printf qq{%s after %d of %d attempts (timeout of %d)\n}, ($success) ? q{Success} : q{Failure}, $attempts, $tries, $timeout;
-    } timeout => 1;
-
-Is essentially equivalent to,
-
-    local $SIG{ALRM} = sub { print qq{ Wake Up!!!!\n} };
-    alarm 1;
-    print qq{ doing something that might timeout ...\n};
-    sleep 6;
-    alarm 0; # reset alarm, end of 'try' block implies this "reset"
-
-=head2 C<retry>
-
-    # Note, the example above of 'try_once' is a reduced case of
-    # 'retry' with 'tries => 1'
+The primary method in this module is meant to be C<retry>,
 
     retry {
       my ($attempts) = @_;                # @_ is populated as described in this line
@@ -174,15 +138,58 @@ Is essentially equivalent to,
       my ( $attempts, $success ) = @_;    # Note: @_ is populated as described in this line when called with retry
       my $tries   = tries;                # "what was the limit on number of tries?" Here it will be 4
       my $timeout = timeout;              # "what was the timeout allowed?" Here it will be 3
-      printf qq{%s after %d of %d attempts (timeout of %d)\n}, ($success) ? q{Success} : q{Failure}, $attempts, $tries, $timeout;
-    }
-    timeout => 3, tries => 4;
 
-This is equivalent to ... well, checkout the implementation of C<Try::ALRM::retry(&;@)>,
+      # test and handle ultimate outcome after attempts
+      if ($successful) {
+        # timeout did NOT occur after $attempts attempts 
+      }
+      else {
+        # timeout DID occur after trying $tries times
+      }
+    } timeout => 3, tries => 4;
+
+Which is equivalent to ... well, checkout the implementation of C<Try::ALRM::retry(&;@)>,
 because it is equivalent to that I<:-)>.
 
-However, it should be pointed out that C<try_once> is a reduced case of C<retry>
-where C<< tries => 1 >>.  There might be benefits to using C<retry> in this way.
+However, it should be pointed out that the module provides a method called, C<try_once>,
+that is a reduced case of C<retry> where C<< tries => 1 >>.  There might be benefits to
+using C<retry> instead, but the code might not ready very clearly with the workd I<retry>.
+Originally, there was a method called C<try>, but because this might conflict with a more
+popular module that exports a C<try> keyword, the decision was made to use C<try_once>.
+It's not pretty, but it's clear.
+
+    use Try::ALRM;
+     
+    try_once {
+      my ($attempts) = @_;                # @_ is populated as described in this line
+      print qq{ doing something that might timeout ...\n};
+      sleep 6;
+    }
+    ALRM {
+      my ($attempts) = @_;                # @_ is populated as described in this line
+      print qq{ Wake Up!!!!\n};
+    }
+    finally {
+      my ( $attempts, $successful ) = @_; # Note: @_ is populated as described in this line when called with retry
+      my $tries   = tries;                # "what was the limit on number of tries?" Here it will be 4
+      my $timeout = timeout;              # "what was the timeout allowed?" Here it will be 3
+
+      # test and handle ultimate outcome after attempts
+      if ($successful) {
+        # timeout did NOT occur after $attempts attempts 
+      }
+      else {
+        # timeout DID occur after trying $tries times
+      }
+    } timeout => 1;
+
+Which is essentially equivalent to just,
+
+    local $SIG{ALRM} = sub { print qq{ Wake Up!!!!\n} };
+    alarm 1;
+    print qq{ doing something that might timeout ...\n};
+    sleep 6;
+    alarm 0; # reset alarm, end of 'try' block implies this "reset"
 
 =head1 DESCRIPTION
 
@@ -197,7 +204,7 @@ as an exception. Which makes it a more natural to write and read in Perl.
 
 Internally, the I<keywords> are implemented as prototypes and uses the same
 sort of coersion of a lexical bloc to a subroutine reference that is used
-in C<Try::Tiny>.
+in L<Try::Tiny>.
 
 =head1 EXPORTS
 
@@ -210,7 +217,7 @@ one of them is I<required> to invoke any benefits of using this module.
 
 =item C<try_once BLOCK>
 
-Not meant to be used with C<Try::ARLM::retry>.
+Meant to be used I<instead> of C<Try::ARLM::retry>.
 
 Primary BLOCK, attempted once with a timeout set by C<$Try::ALRM::TIMEOUT>. If
 an C<ALRM> signal is sent, the BLOCK described by C<ALRM> will be called to handle
@@ -225,7 +232,7 @@ independant implementation.
 
 =item C<retry BLOCK>
 
-Not meant to be used with C<Try::ARLM::try>.
+Meant to be the primary method, not to be used with C<Try::ARLM::try_once>.
 
 Primary BLOCK, attempted C<$Try::ALRM::TRIES> number of times with a timeout
 governed by C<$Try::ALRM::TIMEOUT>. If an C<ALRM> signal is sent and the number
@@ -234,18 +241,28 @@ This continues until an C<ALRM> signal is not triggered or if the number of
 C<$Try::ALRM::TRIES> has been reached.
 
 Accepts blocks: C<ALRM>, C<finally>; and trailing modifiers C<< timeout => INT >>,
-and C<< retries => INT >>.
+and C<< tries => INT >>.
 
 C<retry> makes values available to each C<BLOCK> that is called via C<@_>, see
 description of each BLOCK below for more details. This also applies to the BLOCK
 provided for C<retry>.
 
+I<NB>:
+
+B<BLOCK> is treated as a C<CODE> block internally, and is passed a single value
+that defines what number attempt, please see the examples; all of which contain
+lines such as,
+
+  my $attempts = shift;
+  ...
+
 =item C<ALRM BLOCK>
 
 Optional.
 
-Called when an C<ALRM> signal is detected. If no C<ALRM> BLOCK is defined, then
-the default C<$SIG{ALRM}> handler mechanism is invoked. 
+Called when an C<ALRM> signal is detected. If no C<ALRM> BLOCK is defined and
+C<$SIG{ALRM}> is not a assigned a C<CODE> ref to handle an I<ALRM> signal, then
+not including the C<ALRM> block ends up being a I<no-op> in most cases.
 
 When called with C<retry>, C<@_> contains the number of attempts that have been
 made so far.
@@ -257,6 +274,15 @@ made so far.
     my ($attempts) = @_;
   };
 
+I<NB>:
+
+B<BLOCK> is treated as a C<CODE> block internally, and is passed a single value
+that defines what number attempt, please see the examples; all of which contain
+lines such as,
+
+  my $attempts = shift;
+  ...
+
 =item C<finally BLOCK>
 
 Optional.
@@ -270,13 +296,20 @@ if C<ALRM> had been invoked;
 
   ...
   finally {
-    my ($tries, $succeeded) = @; 
+    my ($attempts, $succeedful) = @_; 
   };
 
 When used with C<try_once>, C<@_> is empty. Note that C<try_once> is essentially a trival case
 of C<retry> with C<< tries => 1 >>; and in the future it may just become a wrapper around
 this case.
 
+B<BLOCK> is treated as a C<CODE> block internally, and is passed a single value
+that defines what number attempt, please see the examples; all of which contain
+lines such as,
+
+  my ($attempts, $successful) = @_;
+  ...
+
 =item C<timeout INT>
 
 Setter/getter for C<$Try::ALRM::TIMEOUT>, which governs the default timeout in number
@@ -293,6 +326,9 @@ that is supported via C<try_once> and C<retry>.
 
 Can be overridden by I<trailing modifier>, C<< timeout => INT >>.
 
+The default value is in the code, but at the time of this writing
+it is set to B<60> seconds.
+
 =item C<tries INT>
 
 Setter/getter for C<$Try::ALRM::TRIES>, which governs the number of attempts C<retry>
@@ -310,17 +346,22 @@ C<< tries => INT >> that is supported via C<retry>.
 
 Can be overridden by I<trailing modifier>, C<< tries => INT >>.
 
+The default value is in the code, but at the time of this writing
+it is set to B<3> attempts.
+
 =back
 
 =head1 PACKAGE ENVIRONMENT
 
-This module exposes C<$Try::ALRM::TIMEOUT> and C<$TRY::ALRM::TRIES> as a
-package variables; it can be modified in traditional ways. The module also
-provides ways to deal with it, continue reading to learn how.
+This module exposes C<$Try::ALRM::TIMEOUT> and C<$TRY::ALRM::TRIES> as
+package variables; they can be modified in traditional ways. The module also
+provides different ways to set these at both script or package scope (using
+the C<timeout> and C<tries> setters, respectively), and at a local execution
+scope (using I<trailing modifiers>.
 
 =head1 USAGE
 
-C<Try::ALRM> doesn't really have options, it's more of a structure. So this
+L<Try::ALRM> doesn't really have options, it's more of a structure. So this
 section is meant to descript that structure and ways to control it. 
 
 =over 4
@@ -381,15 +422,34 @@ is being invoked as the exception handler.
 
 =head1 TRAILING MODIFIERS
 
-=head2 Setting the Timeout
+A side effect of using Perl I<prototypes> to achieve the block structure of this module
+is that passing options is much more naturally done so as a comma delimited list of
+trailing I<key>/I<value> pairs at the end of the entire stucture.
 
-The timeout value passed to C<alarm> internally is controlled with the package variable,
-C<$Try::ALRM::TIMEOUT>. This module presents 2 different ways to control the value of
-this variable.
+As has been show in the previous examples, the modifiers are specifed as follows:
+
+  retry {
+    ...
+  }
+  ALRM {
+    ...
+  },
+  finally {
+    ...
+  } timeout => 5, tries => 10;
+
+  #^^ Note, there is NO comma between the closing '}' and 'timeout'; this
+  # is due the implementation using a prototype that results in keyword syntax
+  # similar to grep or map, e.g., map { } key1 => $val1, key2 => $val2;
+
+This style of providing modifiers to the behavior of the C<retry>/C<try_once>
+block is referred to here as I<trailing modifiers>.
+
+This module has two trailing modifiers that can be set.
 
 =over 4
 
-=item C<timeout>
+=item C<< timeout => INT >>
 
 Due to limitations with the way Perl prototypes work for creating syntactical structures,
 the most idiomatic solution is to use a setter/getter function to update the package
@@ -419,10 +479,20 @@ block into a subroutine reference (i.e., C<CODE>). The I<< key => value >> synta
 a compromise because it makes things a lot more clear I<and> makes the implementation of the
 blocks a lot easier (use the source to see how, I<Luke>).
 
+The timeout value passed to C<alarm> internally is controlled with the package variable,
+C<$Try::ALRM::TIMEOUT>. So this module presents 2 different ways to control the value of
+this variable.
+
 The addition of this timeout affects $Try::ALRM::TIMEOUT for the duration of the C<try_once> block,
 internally is using C<local> to set C<$Try::ALRM::TIMEOUT>. The reason for this is so that
 C<timeout> may continue to function properly as a getter I<inside> of the C<try_once> block.
 
+=item C<< tries => INT >>
+
+Sets the number of attempts made by a C<retry> block. Impacts the value of C<Try::ALRM::TIMEOUT>
+locally for each C<retry> block. See code examples in this document to see what a C<retry>
+block with C<< tries => INT >> looks like.
+
 =back
 
 =head3 C<try_once>/C<ALRM>/C<finally> Examples
@@ -481,7 +551,10 @@ set to the RHS value of C<< tries => >>.
 
 =head1 Bugs
 
-Very likey.
+Very likey. This project was motivated by a couple of factors: learning
+more about Perl I<prototypes> (which this author finds awesome) and
+seeing if C<ALRM> can be treated as a localized exception (turns out,
+I<it can!>).
 
 Milage May Vary, as I<they> say. If found, please file issue on GH repo.
 
@@ -493,10 +566,17 @@ I will find them eventually.
 
 oodler577
 
+=head1 PERL ADVENT 2022
+
+  | \__ `\O/  `--  {}    \}    {/    {}    \}    {/    {}    \} 
+  \    \_(~)/_..___/=____/=____/=____/=____/=____/=____/=____/=*
+   \=======/    //\\  >\/> || \>  //\\  >\/> || \>  //\\  >\/> 
+  ----`---`---  `` `` ```` `` ``  `` `` ```` `` ``  ````  ````
+
 =head1 ACKNOWLEDGEMENTS
 
-"I<To the least of you among of all of us. You make more of a difference
-than any of you will ever know.>" -Anonymous
+"I<This module is dedicated to the least of you amongst us and to all
+of those who have died suddenly.>"
 
 =head1 COPYRIGHT AND LICENSE
 
